function [streamingEnabled, availableBuffer]  = hACQGetSpectrumDataStreamingStatus(instrument)
%function [streamingEnabled, availableBuffer]  = hACQGetSpectrumDataStreamingStatus(instrument)
%Returns the enabled status and buffer utilization for spectrum streaming
%
%Parameters:
%instrument - The tcp-ip object that is connected to the Hyperion Instrument.
%
%Return Values:
%
%streamingEnabled - This is 1 if spectrum streaming is enabled, 0 if disabled.
%availableBuffer - This is the percent of the streaming buffer that is
%available.  If data is being consumed by the client as fast as it is being
%delivered, then this will be at or near 100

response = hCOMMExecuteCommand(instrument, '#GetFullSpectrumDataStreamingStatus','',0,1);
streamingEnabled = typecast(response.content, 'uint32');

if streamingEnabled
    response = hCOMMExecuteCommand(instrument, '#GetFullSpectrumDataStreamingAvailableBuffer','',0,1);
    availableBuffer = typecast(response.content, 'uint32');
else
    availableBuffer = 0;
end
    